Skip to content

lib: igt@i915_suspend@shrink faster

Caz Yokoyama igt-dev intel-gfx 1 version In review

Get series with b4
b4 am [email protected]

Versions newest first

  1. v1 Latest1 patch 1 replyIn review

Patches in v1 No applies recorded yet

#Subject and filesSizeRepliesApplied
1/1igt@i915_suspend@shrink fasterlib/intel_os.c+1 -112 replies

Reviews trailers per patch

No Reviewed-by, Acked-by or Tested-by trailers for v1 yet.

Read the v1 thread

Cover letter [igt-dev] [igt PATCH 0/1] lib: igt@i915_suspend@shrink faster

igt@i915_suspend@shrink runs 25 sec instead of 90 sec on my NUC which has 2GB of memory. The child process which is created by igt_fork() updates pinnable memory size, (*can_mlock). Parent process mlocks at the end of "for loop" when the child process finds pinnable memory size in 4kb boundary. This patch also reduces the chance of dying entire test process because the parent process mclocks the memory where we already know it is pinnable.

Incrementary mlocking small memory in addition to 3/4 of available memory by the child process does not work because kernel finds the parent process mlocks more memory than the child process and kills the parent process.

Another big time consumer is igt_system_suspend_autoresume(). 15 sec of delay is hard coded. It is too danger to reduce 15 sec because some of test machines may fail by reducing delay time.

"gem_userptr_blits@mlocked-*" test also calls intel_get_total_pinnable_mem(). I do not test them because they do not finish within 30 min on my NUC without this patch.

Caz Yokoyama (1):
igt@i915_suspend@shrink faster

 lib/intel_os.c | 2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)
Signature · 6 lines
2.17.1

_______________________________________________
igt-dev mailing list
[email protected]
https://lists.freedesktop.org/mailman/listinfo/igt-dev